class ImagesController < ApplicationController
  # Allow unauthenticated access to index and show actions
  # allow_unauthenticated_access only: [:index, :show, :search]

  before_action :set_image, only: [ :show, :edit, :update, :destroy, :approve, :reject ]
  before_action :authorize_admin, only: [ :approve, :reject, :destroy ]

  def index
    @q = Image.includes(:user, :tags).ransack(params[:q])
    @images = @q.result(distinct: true).with_attached_file.order(created_at: :desc).page(params[:page]).per(12)

    respond_to do |format|
      format.html do
        render inertia: "images/Index", props: {
          images: @images.as_json(include: [ :user, :tags ], methods: [ :file_url ]),
          filters: params[:q] || {},
          pagination: {
            current_page: @images.current_page,
            total_pages: @images.total_pages,
            total_count: @images.total_count
          }
        }
      end

      format.json do
        render json: {
          images: @images.as_json(include: [ :user, :tags ], methods: [ :file_url ]),
          pagination: {
            current_page: @images.current_page,
            total_pages: @images.total_pages,
            total_count: @images.total_count
          }
        }
      end
    end
  end

  def show
    render inertia: "images/Show", props: {
      image: @image.as_json(include: [ :user, :tags ], methods: [ :file_url ]),
      can_edit: Current.user == @image.user,
      can_approve: Current.user&.admin?
    }
  end

  def new
    @image = Image.new
    render inertia: "images/New"
  end

  def create
    @image = Current.user.images.new(image_params)

    if @image.save
      if params[:tags].present?
        @image.add_tags(params[:tags].split(","))
      end
      redirect_to image_path(@image), notice: "Image was successfully uploaded and is pending review."
    else
      render inertia: "images/New", props: {
        image: @image.as_json(methods: [ :errors ]),
        errors: @image.errors
      }, status: :unprocessable_entity
    end
  end

  def edit
    authorize_user
    render inertia: "images/Edit", props: {
      image: @image.as_json(include: [ :tags ], methods: [ :file_url ]),
      tags: @image.tags.pluck(:name).join(", ")
    }
  end

  def update
    authorize_user

    if @image.update(image_params)
      if params[:tags].present?
        @image.tags.clear
        @image.add_tags(params[:tags].split(","))
      end
      redirect_to image_path(@image), notice: "Image was successfully updated."
    else
      render inertia: "images/Edit", props: {
        image: @image.as_json(include: [ :tags ], methods: [ :file_url, :errors ]),
        tags: params[:tags],
        errors: @image.errors
      }, status: :unprocessable_entity
    end
  end

  def destroy
    @image.destroy
    redirect_to images_path, notice: "Image was successfully deleted."
  end

  def search
    @q = Image.approved.includes(:user, :tags).ransack(params[:q])
    @images = @q.result(distinct: true).with_attached_file.order(created_at: :desc).page(params[:page]).per(12)

    render inertia: "images/Search", props: {
      images: @images.as_json(include: [ :user, :tags ], methods: [ :file_url ]),
      filters: params[:q] || {},
      tags: Tag.all.pluck(:name)
    }
  end

  def approve
    @image.approved!
    redirect_to image_path(@image), notice: "Image was successfully approved."
  end

  def reject
    @image.rejected!
    redirect_to image_path(@image), notice: "Image was rejected."
  end

  private

  def set_image
    @image = Image.find(params[:id])
  end

  def image_params
    params.require(:image).permit(:title, :file)
  end

  def authorize_user
    unless Current.user == @image.user
      redirect_to images_path, alert: "You are not authorized to perform this action."
    end
  end

  def authorize_admin
    unless Current.user&.admin?
      redirect_to images_path, alert: "You are not authorized to perform this action."
    end
  end
end
