import { useState, useEffect, useRef, useCallback } from 'react'
import { Head, Link, router } from '@inertiajs/react'
import Layout from '../Layout'
import * as Form from '@radix-ui/react-form'
import * as Collapsible from '@radix-ui/react-collapsible'
import { uniqBy } from 'lodash-es'

export default function Index({ images, filters, pagination, auth }) {
  const [allImages, setAllImages] = useState(images || [])
  const [page, setPage] = useState(pagination?.current_page || 1)
  const [maxVisiblePage, setMaxVisiblePage] = useState(0)

  const [loading, setLoading] = useState(false)
  const [hasMore, setHasMore] = useState(pagination?.current_page < pagination?.total_pages)
  const [loadedPageMap, setLoadedPageMap] = useState({})
  const bottomObserver = useRef()
  const [searchParams, setSearchParams] = useState({
    title_cont: filters.title_cont || '',
    tags_name_cont: filters.tags_name_cont || '',
    created_at_gteq: filters.created_at_gteq || '',
    created_at_lteq: filters.created_at_lteq || '',
  })
  const [isFilterOpen, setIsFilterOpen] = useState(false)

  const handleInputChange = (e) => {
    const { name, value } = e.target
    setSearchParams({ ...searchParams, [name]: value })
  }

  const handleSearch = (e) => {
    e.preventDefault()
    setLoadedPageMap({})
    maxVisiblePage(0)
    setAllImages([])

    loadPage(1)
  }

  const loadPage = async (currentPage) => {
    if (loadedPageMap[currentPage]) {
      return loadedPageMap[currentPage];
    }

    try {
      setLoading(true)

      await router.visit(
        '/images', 
        {
          method: 'get',
          data: { 
            page: currentPage,
            q: {
              title_cont: searchParams.title_cont,
              tags_name_cont: searchParams.tags_name_cont,
              created_at_gteq: searchParams.created_at_gteq,
              created_at_lteq: searchParams.created_at_lteq
            }
          },
          preserveState: true,
          preserveScroll: true,
          replace: true,
          only: ['images', 'pagination'],
          onSuccess: (response) => {
            // Prepend new images to existing ones
            setPage(response.props.pagination.current_page)
            setHasMore(maxVisiblePage < response.props.pagination.total_pages)
            console.log('response', response);
            
            setLoadedPageMap({...loadedPageMap, [response.props.pagination.current_page]: response.props.images})
            setLoading(false)
          },
          onError: () => {
            console.error('Error loading images')
            setLoading(false)
          }
        })
    } catch (error) {
      console.error('Error loading images:', error)
      setLoading(false)
    }
  }

  const setVisibleImages = async (expectPage) =>{
    if (!loadedPageMap[expectPage]) {
      await loadPage(expectPage)
    }
    setAllImages(uniqBy([...allImages, ...(loadedPageMap[expectPage] || [])], (image) => image.id))
    setMaxVisiblePage(expectPage)
  }

  useEffect(() => {
    if (page >= 1 && !loadedPageMap[1]) {
      setVisibleImages(1)
    } else {
      setVisibleImages(page)
    }
  }, [page, loadedPageMap, maxVisiblePage])

  const loadMoreImages = useCallback(() => {
    loadPage(page + 1)
  }, [page, loadPage])

  // Observer for the last image (bottom of the page)
  const lastImageElementRef = useCallback(node => {
    if (loading) return
    if (bottomObserver.current) bottomObserver.current.disconnect()
    
    bottomObserver.current = new IntersectionObserver(entries => {
      if (entries[0].isIntersecting && hasMore) {
        loadMoreImages()
      }
    }, { threshold: 0.1, rootMargin: '100px' })
    
    if (node) bottomObserver.current.observe(node)
  }, [loading, hasMore, loadMoreImages])

  return (
    <Layout user={auth}>
      <Head title="My Images" />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6 flex justify-between items-center">
          <div>
            <h1 className="text-2xl font-bold text-gray-900">My Images</h1>
            <p className="mt-1 max-w-2xl text-sm text-gray-500">
              Manage your uploaded images
            </p>
          </div>
          <div className="flex space-x-2">
            <button
              onClick={() => setIsFilterOpen(!isFilterOpen)}
              className="inline-flex items-center px-3 py-2 border border-gray-300 text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M3 4a1 1 0 011-1h16a1 1 0 011 1v2.586a1 1 0 01-.293.707l-6.414 6.414a1 1 0 00-.293.707V17l-4 4v-6.586a1 1 0 00-.293-.707L3.293 7.293A1 1 0 013 6.586V4z" />
              </svg>
              {isFilterOpen ? 'Hide Filters' : 'Show Filters'}
            </button>
            {auth && (
              <Link
              href="/images/new"
              className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              Upload New Image
            </Link>
            )}
          </div>
        </div>

        <div className="px-4 sm:px-6 pb-5">
          <Collapsible.Root open={isFilterOpen} onOpenChange={setIsFilterOpen} className="w-full">
            <Collapsible.Content className="mb-6 mt-4 overflow-hidden">
              <Form.Root
                className="space-y-6 border border-gray-200 rounded-md p-4 bg-gray-50"
                onSubmit={handleSearch}
              >
                <div className="grid grid-cols-1 gap-y-6 gap-x-4 sm:grid-cols-6">
                  <div className="sm:col-span-3">
                    <Form.Field name="title_cont">
                      <Form.Label className="block text-sm font-medium text-gray-700">
                        Title
                      </Form.Label>
                      <Form.Control asChild>
                        <input
                          type="text"
                          name="title_cont"
                          value={searchParams.title_cont}
                          onChange={handleInputChange}
                          className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                          placeholder="Search by title"
                        />
                      </Form.Control>
                    </Form.Field>
                  </div>

                  <div className="sm:col-span-3">
                    <Form.Field name="tags_name_cont">
                      <Form.Label className="block text-sm font-medium text-gray-700">
                        Tags
                      </Form.Label>
                      <Form.Control asChild>
                        <input
                          type="text"
                          name="tags_name_cont"
                          value={searchParams.tags_name_cont}
                          onChange={handleInputChange}
                          className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                          placeholder="Search by tag"
                        />
                      </Form.Control>
                    </Form.Field>
                  </div>

                  <div className="sm:col-span-3">
                    <Form.Field name="created_at_gteq">
                      <Form.Label className="block text-sm font-medium text-gray-700">
                        From Date
                      </Form.Label>
                      <Form.Control asChild>
                        <input
                          type="date"
                          name="created_at_gteq"
                          value={searchParams.created_at_gteq}
                          onChange={handleInputChange}
                          className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        />
                      </Form.Control>
                    </Form.Field>
                  </div>

                  <div className="sm:col-span-3">
                    <Form.Field name="created_at_lteq">
                      <Form.Label className="block text-sm font-medium text-gray-700">
                        To Date
                      </Form.Label>
                      <Form.Control asChild>
                        <input
                          type="date"
                          name="created_at_lteq"
                          value={searchParams.created_at_lteq}
                          onChange={handleInputChange}
                          className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        />
                      </Form.Control>
                    </Form.Field>
                  </div>
                </div>

                <div className="flex justify-end">
                  <button
                    type="submit"
                    className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    Search
                  </button>
                </div>
              </Form.Root>
            </Collapsible.Content>
          </Collapsible.Root>
          
          {allImages.length > 0 ? (
            <div className="grid grid-cols-1 gap-6 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 mt-6">
                {loading && (
                  <div className="col-span-full text-center py-4">
                    <div className="inline-block h-8 w-8 animate-spin rounded-full border-4 border-solid border-current border-r-transparent align-[-0.125em] motion-reduce:animate-[spin_1.5s_linear_infinite]" role="status">
                      <span className="!absolute !-m-px !h-px !w-px !overflow-hidden !whitespace-nowrap !border-0 !p-0 ![clip:rect(0,0,0,0)]">
                        Loading...
                      </span>
                    </div>
                  </div>
                )}
                {allImages.map((image, index) => (
                  <div
                    key={image.id}
                    ref={index === allImages.length - 1 ? lastImageElementRef : null}
                    className="bg-white overflow-hidden shadow rounded-lg"
                  >
                    <div className="relative pb-[75%]">
                      <img
                        loading="lazy"
                        src={image.file_url}
                        alt={image.title}
                        className="absolute h-full w-full object-cover"
                      />
                      <div className="absolute top-2 right-2">
                        <span
                          className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                            image.status === 'pending'
                              ? 'bg-yellow-100 text-yellow-800'
                              : image.status === 'approved'
                              ? 'bg-green-100 text-green-800'
                              : 'bg-red-100 text-red-800'
                          }`}
                        >
                          {image.status}
                        </span>
                      </div>
                    </div>
                    <div className="px-4 py-4">
                      <h3 className="text-lg font-medium text-gray-900 truncate">
                        {image.title}
                      </h3>
                      <div className="mt-2 flex flex-wrap gap-1">
                        {image.tags.map((tag) => (
                          <span
                            key={`tag-${tag.id}`}
                            className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-indigo-100 text-indigo-800"
                          >
                            {tag.name}
                          </span>
                        ))}
                      </div>
                      <div className="mt-4 flex justify-between">
                        <Link
                          href={`/images/${image.id}`}
                          className="text-sm text-indigo-600 hover:text-indigo-900"
                        >
                          View details
                        </Link>
                        <span className="text-sm text-gray-500">
                          {new Date(image.created_at).toLocaleDateString()}
                        </span>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            ) : (
              <div className="text-center py-12">
                {loading && allImages.length === 0 ? (
                  <div className="flex justify-center items-center">
                    <svg className="animate-spin h-8 w-8 text-indigo-600" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                      <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
                      <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                    </svg>
                  </div>
                ) : (
                <div>
                  <svg
                    className="mx-auto h-12 w-12 text-gray-400"
                    fill="none"
                    viewBox="0 0 24 24"
                    stroke="currentColor"
                    aria-hidden="true"
                  >
                    <path
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      strokeWidth={2}
                      d="M4 16l4.586-4.586a2 2 0 012.828 0L16 16m-2-2l1.586-1.586a2 2 0 012.828 0L20 14m-6-6h.01M6 20h12a2 2 0 002-2V6a2 2 0 00-2-2H6a2 2 0 00-2 2v12a2 2 0 002 2z"
                    />
                  </svg>
                  <h3 className="mt-2 text-sm font-medium text-gray-900">
                    No images
                  </h3>
                  <p className="mt-1 text-sm text-gray-500">
                    Get started by uploading a new image.
                  </p>
                  <div className="mt-6">
                    <Link
                      href="/images/new"
                      className="inline-flex items-center px-4 py-2 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                    >
                      Upload New Image
                    </Link>
                  </div>
                </div>
                )}
              </div>
            )}
          {loading && allImages.length > 0 && (
            <div className="flex justify-center mt-6 pb-6">
              <svg className="animate-spin h-8 w-8 text-indigo-600" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
                <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
              </svg>
            </div>
          )}
        </div>
      </div>
    </Layout>
  )
}
