import { useState } from 'react'
import { Head, useForm, router } from '@inertiajs/react'
import Layout from '../Layout'
import * as Form from '@radix-ui/react-form'

export default function New({ auth, errors = {} }) {
  const [preview, setPreview] = useState(null)
  const { data, setData, processing } = useForm({
    title: '',
    file: null,
    tags: '',
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    router.post('/images', { image: data })
  }

  const handleFileChange = (e) => {
    const file = e.target.files[0]
    setData('file', file)
    
    if (file) {
      const reader = new FileReader()
      reader.onloadend = () => {
        setPreview(reader.result)
      }
      reader.readAsDataURL(file)
    } else {
      setPreview(null)
    }
  }

  return (
    <Layout user={auth.user}>
      <Head title="Upload New Image" />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6">
          <h1 className="text-2xl font-bold text-gray-900">Upload New Image</h1>
          <p className="mt-1 max-w-2xl text-sm text-gray-500">
            Upload a new image for review
          </p>
        </div>
        <div className="border-t border-gray-200 px-4 py-5 sm:px-6">
          <Form.Root className="space-y-6" onSubmit={handleSubmit}>
            <Form.Field name="title" className="space-y-2">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Title
              </Form.Label>
              <Form.Control asChild>
                <input
                  type="text"
                  name="title"
                  value={data.title}
                  onChange={(e) => setData('title', e.target.value)}
                  className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                  placeholder="Enter image title"
                />
              </Form.Control>
              {errors.title && (
                <Form.Message className="text-sm text-red-600">
                  {errors.title}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="file" className="space-y-2">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Image File
              </Form.Label>
              <div className="mt-1 flex justify-center px-6 pt-5 pb-6 border-2 border-gray-300 border-dashed rounded-md">
                <div className="space-y-1 text-center">
                  {preview ? (
                    <div className="mb-4">
                      <img
                        src={preview}
                        alt="Preview"
                        className="mx-auto h-64 object-contain"
                      />
                    </div>
                  ) : (
                    <svg
                      className="mx-auto h-12 w-12 text-gray-400"
                      stroke="currentColor"
                      fill="none"
                      viewBox="0 0 48 48"
                      aria-hidden="true"
                    >
                      <path
                        d="M28 8H12a4 4 0 00-4 4v20m32-12v8m0 0v8a4 4 0 01-4 4H12a4 4 0 01-4-4v-4m32-4l-3.172-3.172a4 4 0 00-5.656 0L28 28M8 32l9.172-9.172a4 4 0 015.656 0L28 28m0 0l4 4m4-24h8m-4-4v8m-12 4h.02"
                        strokeWidth={2}
                        strokeLinecap="round"
                        strokeLinejoin="round"
                      />
                    </svg>
                  )}
                  <div className="flex text-sm text-gray-600">
                    <label
                      htmlFor="file-upload"
                      className="relative cursor-pointer bg-white rounded-md font-medium text-indigo-600 hover:text-indigo-500 focus-within:outline-none focus-within:ring-2 focus-within:ring-offset-2 focus-within:ring-indigo-500"
                    >
                      <span>Upload a file</span>
                      <Form.Control asChild>
                        <input
                          id="file-upload"
                          name="file"
                          type="file"
                          className="sr-only"
                          accept="image/*"
                          onChange={handleFileChange}
                        />
                      </Form.Control>
                    </label>
                    <p className="pl-1">or drag and drop</p>
                  </div>
                  <p className="text-xs text-gray-500">
                    PNG, JPG, GIF up to 10MB
                  </p>
                </div>
              </div>
              {errors.file && (
                <Form.Message className="text-sm text-red-600">
                  {errors.file}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="tags" className="space-y-2">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Tags
              </Form.Label>
              <Form.Control asChild>
                <input
                  type="text"
                  name="tags"
                  value={data.tags}
                  onChange={(e) => setData('tags', e.target.value)}
                  className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                  placeholder="Enter tags separated by commas (e.g. nature, landscape, mountains)"
                />
              </Form.Control>
              <p className="text-xs text-gray-500">
                Enter tags separated by commas
              </p>
            </Form.Field>

            <div className="flex justify-end">
              <Form.Submit asChild>
                <button
                  type="submit"
                  disabled={processing}
                  className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50"
                >
                  {processing ? 'Uploading...' : 'Upload Image'}
                </button>
              </Form.Submit>
            </div>
          </Form.Root>
        </div>
      </div>
    </Layout>
  )
}
